@@ -9,7 +9,8 @@ setRIGHT(nameArray = "dummy",
          scriptArray = c(),
          numAxis = 0,
          numPoints = 0,
-         numLines = 0)
+         numLines = 0,
+         numServer = 0)
 
 test_that("data.frame object should exist", {
   
@@ -24,8 +25,10 @@ test_that("data.frame object should exist", {
 
 test_that("Column names should exist", {
   
-  expect_error(plot_RIGHT(conc1 ~ Time, Thoeph, type = "n"))
-  expect_error(plot_RIGHT(conc ~ Time1, Thoeph, type = "n"))
+  expect_error(plot_RIGHT(conc1 ~ Time, Theoph, type = "n"))
+  expect_error(plot_RIGHT(conc ~ Time1, Theoph, type = "n"))
+  expect_error(plot_RIGHT(conc ~ Time, Theoph, type = "n", by = Subject1))
+  expect_error(plot_RIGHT(conc ~ Time, Theoph, type = "n", color = Subject1))
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
   expect_identical(temp$numAxis, 0)
   expect_identical(temp$numPoints, 0)
@@ -72,7 +75,7 @@ test_that("Check script generation without any options", {
                                        "var axis2 = new Axis(2, Theoph, 'Time', 'conc', {});",
                                        "var point1 = new Dot(axis2, Theoph, 'Time', 'conc', {});",
                                        "var axis3 = new Axis(3, Theoph, 'Time', 'conc', {});",
-                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc');",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {});",
                                        "var line1 = new Line(axis3, lineObj1, 'x1', 'x2', 'y1', 'y2', {});"))
   
   plot_RIGHT(conc ~ Time, Theoph, type = "b")
@@ -89,15 +92,33 @@ test_that("Check script generation without any options", {
                                        "var axis2 = new Axis(2, Theoph, 'Time', 'conc', {});",
                                        "var point1 = new Dot(axis2, Theoph, 'Time', 'conc', {});",
                                        "var axis3 = new Axis(3, Theoph, 'Time', 'conc', {});",
-                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc');",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {});",
                                        "var line1 = new Line(axis3, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
                                        "var axis4 = new Axis(4, Theoph, 'Time', 'conc', {});",
-                                       "var lineObj2 = new MakeLineObj(Theoph, 'Time', 'conc');",
+                                       "var lineObj2 = new MakeLineObj(Theoph, 'Time', 'conc', {});",
                                        "var line2 = new Line(axis4, lineObj2, 'x1', 'x2', 'y1', 'y2', {});",
                                        "var point2 = new Dot(axis4, Theoph, 'Time', 'conc', {});"))
   
 }) # test_that
 
+setRIGHT(divArray = c(),
+         scriptArray = c(),
+         numAxis = 0,
+         numPoints = 0,
+         numLines = 0)
+
+test_that("Check by option:", {
+  
+  plot_RIGHT(conc ~ Time, Theoph, type = "b", by = Subject)
+  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
+  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>'))
+  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {});",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line1 = new Line(axis1, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point1 = new Dot(axis1, Theoph, 'Time', 'conc', {});"))
+  
+}) # test_that
+
 setRIGHT(divArray = c(),
          scriptArray = c(),
          numAxis = 0,
@@ -106,31 +127,28 @@ setRIGHT(divArray = c(),
 
 test_that("Check color option:", {
 
-  plot_RIGHT(conc ~ Time, Theoph, type = "n", color = Subject)
-  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
-  expect_identical(temp$divArray, '<div id="container1" oncontextmenu="return false;"></div>')
-  expect_identical(temp$scriptArray, "var axis1 = new Axis(1, Theoph, 'Time', 'conc', {legend: 'Subject'});")
-
-  plot_RIGHT(conc ~ Time, Theoph, type = "p", color = Subject)
-  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
-  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>', 
-                                    '<div id="container2" oncontextmenu="return false;"></div>'))
-  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {legend: 'Subject'});", 
-                                       "var axis2 = new Axis(2, Theoph, 'Time', 'conc', {legend: 'Subject'});",
-                                       "var point1 = new Dot(axis2, Theoph, 'Time', 'conc', {});"))
-
+  expect_error(plot_RIGHT(conc ~ Time, Theoph, by = Dose, color = Subject))
+  
   plot_RIGHT(conc ~ Time, Theoph, type = "b", color = Subject)
   temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
-  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>', 
-                                    '<div id="container2" oncontextmenu="return false;"></div>',
-                                    '<div id="container3" oncontextmenu="return false;"></div>'))
-  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {legend: 'Subject'});", 
+  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>'))
+  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {legend: 'Subject'});",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line1 = new Line(axis1, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point1 = new Dot(axis1, Theoph, 'Time', 'conc', {});"))
+
+  plot_RIGHT(conc ~ Time, Theoph, type = "b", by = Subject, color = Subject)
+  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
+  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>',
+                                    '<div id="container2" oncontextmenu="return false;"></div>'))
+  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {legend: 'Subject'});",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line1 = new Line(axis1, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point1 = new Dot(axis1, Theoph, 'Time', 'conc', {});",
                                        "var axis2 = new Axis(2, Theoph, 'Time', 'conc', {legend: 'Subject'});",
-                                       "var point1 = new Dot(axis2, Theoph, 'Time', 'conc', {});",
-                                       "var axis3 = new Axis(3, Theoph, 'Time', 'conc', {legend: 'Subject'});",
-                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc');",
-                                       "var line1 = new Line(axis3, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
-                                       "var point2 = new Dot(axis3, Theoph, 'Time', 'conc', {});"))
+                                       "var lineObj2 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line2 = new Line(axis2, lineObj2, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point2 = new Dot(axis2, Theoph, 'Time', 'conc', {});"))
   
   # CHECK (junghoon): check what happens if both color and col are set.
   
@@ -140,7 +158,34 @@ test_that("Check col option:", {
   # col option is checked at lines_RIGHT() and points_RIGHT() level.
 }) # test_that
 
+setRIGHT(divArray = c(),
+         scriptArray = c(),
+         numAxis = 0,
+         numPoints = 0,
+         numLines = 0)
+
 test_that("Check isString option:", {
-  # CHECK (junghoon)
-})
+  
+  plot_RIGHT(conc ~ Time, "Theoph", type = "b", by = "Subject", isString = TRUE)
+  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
+  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>'))
+  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {});",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line1 = new Line(axis1, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point1 = new Dot(axis1, Theoph, 'Time', 'conc', {});"))
+
+  plot_RIGHT(conc ~ Time, "Theoph", type = "b", color = "Subject", isString = TRUE)
+  temp <- get(".RIGHT", envir = asNamespace("RIGHT"))
+  expect_identical(temp$divArray, c('<div id="container1" oncontextmenu="return false;"></div>',
+                                    '<div id="container2" oncontextmenu="return false;"></div>'))
+  expect_identical(temp$scriptArray, c("var axis1 = new Axis(1, Theoph, 'Time', 'conc', {});",
+                                       "var lineObj1 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line1 = new Line(axis1, lineObj1, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point1 = new Dot(axis1, Theoph, 'Time', 'conc', {});",
+                                       "var axis2 = new Axis(2, Theoph, 'Time', 'conc', {legend: 'Subject'});",
+                                       "var lineObj2 = new MakeLineObj(Theoph, 'Time', 'conc', {group: 'Subject'});",
+                                       "var line2 = new Line(axis2, lineObj2, 'x1', 'x2', 'y1', 'y2', {});",
+                                       "var point2 = new Dot(axis2, Theoph, 'Time', 'conc', {});"))
+
+}) # test_that
 
